/******************************************************************************/
//
// Name: 	Programming SRC on ADSP-21364 SHARC(R) DSP Processor
//
/******************************************************************************

(C) Copyright 2005 - Analog Devices, Inc.  All rights reserved.

File Name:		main.c

Date Modified:	11/04/05	-	AV	-	Rev 1.0

Software:       VisualDSP++3.5 (November update)

Purpose:		To demonstrate SRC programming on ADSP-21364
				
*******************************************************************************/
#include "tt.h"

//Function definition
void SRC0Init();

void Sport0Init();
void Sport1Init();

void SRC0_SRC1_With_DAI();
void SPORT0_SPORT1_With_SRCs();

void Sport0RxIsr(int dummy);
void Irq1ISR(int dummy1);

void SetupIRQ ();

//Global variables
int RX_VALUE;
int IRQ1_ISR_FLAG = 0;

void main(void)
{
    
	//InitPLL ();  //use this to change the core clock if needed
	
	Init1835viaSPI();//-- Initialize AD1835 codec via SPI
	
	SRC0_SRC1_With_DAI();//-- Connect SRC0,1 with DAI pins
	SPORT0_SPORT1_With_SRCs();//-- Connect SPORT0,1 internally with SRCs using SRU
	
	Sport1Init();//-- Initialize SPORT1
	Sport0Init();//-- Initialize SPORT0
	
	SRC0Init();//-- Initialize SRC0,1
	
	interrupts(SIG_P6,Sport0RxIsr);//--Set up sport0 interrupt
	
	
	SetupIRQ ();
	interrupt (SIG_IRQ1,Irq1ISR);

	while(1)
	{
	}
	
}	




//Initialize SRC0,1
//----------------------------------------------------------------------------------
void SRC0Init()
{
	*pSRCRAT0 |= SRC1_MUTEOUT;
	*pSRCMUTE = SRC1_MUTE_EN;
	*pSRCCTL0 = SRC0_SMODEIN0 | SRC0_SMODEOUT0 | SRC0_RESET | SRC1_SMODEIN0 | SRC1_SMODEOUT0 | SRC1_RESET;//VDSP++3.5
}
//----------------------------------------------------------------------------------



//Initialize SPORT0
//----------------------------------------------------------------------------------
void Sport0Init()
{
	*pDIV0 = 0x0018001e;
	*pSPCTL0 |= SPEN_A | SLEN24 | MSTR | OPMODE ;	//SPORT0 configuration:
													//Internal clock and word select 
													//I2S mode
													//Receiver
													//Word length 24
}
//----------------------------------------------------------------------------------



//Initialize SPORT1
//----------------------------------------------------------------------------------
void Sport1Init()
{
	*pDIV1 = 0x0018001e;
	*pSPCTL1 |= SPEN_A | SLEN24 | MSTR | OPMODE | SPTRAN;//SPORT1 configuration:
														 //Internal clock and word select 
														 //I2S mode
														 //Transmitter
														 //Word length 24
}
//----------------------------------------------------------------------------------



//SPORT0 Receive Interrupt 
//----------------------------------------------------------------------------------
void Sport0RxIsr(int dummy)
{
	
	RX_VALUE = *pRXSP0A;
	*pTXSP1A = RX_VALUE;
	
}
//----------------------------------------------------------------------------------




//External Interrupt set-up
//----------------------------------------------------------------------------------
void SetupIRQ ()
{
    //Enable the pin as IRQ1
    *pSYSCTL|= IRQ1EN;

    asm ("#include <def21364.h>") ;
    
    //Set the IRQ pin to be edge sensitive
    asm ("bit set mode2 IRQ1E;") ;
}
//----------------------------------------------------------------------------------



//Interrupt routine to mute/unmute SRC1
//----------------------------------------------------------------------------------
void Irq1ISR(int dummy1)
{
	if(IRQ1_ISR_FLAG==0)
	{
		*pSRCCTL0 |= SRC1_SOFTMUTE;
		IRQ1_ISR_FLAG = 1;
	}
	else
	{
		*pSRCCTL0 &= ~SRC1_SOFTMUTE;
		IRQ1_ISR_FLAG =0;
	}
	
}
//----------------------------------------------------------------------------------
